@@ -5,17 +5,21 @@ test_that("epmc_db returns", {
   a <- epmc_db("12368864", db = "uniprot", limit = 50)
   b <- epmc_db("25249410", db = "embl")
   c <- epmc_db("14756321", db = "uniprot")
+  d <- epmc_db("11805837", db = "pride")
 
   #correct dimensions and class
   expect_output(str(a), "data.frame")
   expect_output(str(b), "data.frame")
   expect_output(str(c), "data.frame")
+  expect_output(str(d), "data.frame")
+
 
   expect_is(attr(a, "hit_count"), "integer")
   expect_is(attr(b, "hit_count"), "integer")
   expect_is(attr(c, "hit_count"), "integer")
+  expect_is(attr(d, "hit_count"), "integer")
 
-   expect_equal(nrow(a), 50)
+  expect_equal(nrow(a), 50)
 
   # fails correctly
   expect_error(epmc_db("14756321"), "Please restrict reponse to a database")
